from h5py import File, Group
from thd_json import detector
from h5schemas.scan_schema import open_schema
from h5schemas.initialize_dataset import initialize_dataset


def init_detector(
    h5_file: File | Group,
    detector_image_dimensions_px: tuple[int, int],
    pixel_pitch_mm: tuple[float, float],
):
    # Get schemas and add them to the File | Group
    schema_groups = get_detector_schemas()
    initialize_dataset(h5_file, schema_groups)
    add_detector_sample(h5_file, detector_image_dimensions_px, pixel_pitch_mm)


def add_detector_sample(
    h5_file: File | Group,
    detector_image_dimensions_px: tuple[int, int],
    pixel_pitch_mm: tuple[float, float],
):
    dst = h5_file["image_dimensions_px/u"]
    dst.resize((dst.shape[0] + 1,))
    dst[-1,] =  detector_image_dimensions_px[0]

    dst = h5_file["image_dimensions_px/v"]
    dst.resize((dst.shape[0] + 1,))
    dst[-1,] =  detector_image_dimensions_px[1]

    dst = h5_file["pixel_pitch_mm/v"]
    dst.resize((dst.shape[0] + 1,))
    dst[-1,] =  pixel_pitch_mm[0]

    dst = h5_file["pixel_pitch_mm/v"]
    dst.resize((dst.shape[0] + 1,))
    dst[-1,] =  pixel_pitch_mm[1]



def get_detector_schemas():
    return open_schema(detector, "detector.json")


if __name__ == "__main__":
    test_file = File("./examples/detector.h5", "w")
    init_detector(test_file, (128, 128), (0.139, 0.139))
